@@ -169,7 +169,7 @@ Creates an X.509 certificate and key.
 
 This script was originally designed for SHEBANGS, a JISC funded project at The University of Manchester.
 http://www.mc.manchester.ac.uk/projects/shebangs/
-E<0x0a>now http://www.rcs.manchester.ac.uk/projects/shebangs/
+ now http://www.rcs.manchester.ac.uk/projects/shebangs/
 
 Mailing list, shebangs@listserv.manchester.ac.uk
 
